==> kado-4.0.0.tgz: package/doc/article/Kado4Released.md <==
# Kado 4 Released
*By Bryan Tong on 2/19/20*

We are proud to announce Kado 4 has been released to the general public! Our new
version of Kado has been 6 months in the making, over 550+ commits. There are
37 top level libraries that provide a wealth of functionality! All the code
strictly follows [standard.js](https://standardjs.com) code styling.

Kado 4 is a ground up rewrite working through a new approach to providing the
same functionality as Kado 3 in a much more open manner. Kado 4 also provides
core libraries that replace the need for over 50+ packages! Kado 4 is fully
unit tested with over 600 tests!

## Faster than Ever

We set a primary goal when developing Kado 4 and that was to reduce the latency
of web requests. Our current applications were just too slow. Kado 4 boosts
response time by over 50 times and probably more! The time on requests drops
closer to compiled levels with Kado 4 and we promise it will out perform your
current setup.

## Create Websites and API Servers

The new Kado libraries come with enough functionality to setup both websites
and API servers right out of the box. No extra dependencies needed! The included
libraries provide everything to setup routes, process requests, and set
redirects. Keep working close to the core of Node.JS by using Kado for your next
servers.

## Step by Step Guides

Check out [kado.org](https://kado.org) if you are not already there and see
the **Guides** section at the left. The guides link together to form a step
by step introduction into using Kado 4 in your application.

## Built in Testing

Kado 4 is proud to announce the ability to write and run tests directly using
the included [TestRunner](../TestRunner.md) library. Also see the
[Writing Tests](../guides/WritingTests.md) guide to gain more understanding
on constructing test suites.

## Open Development with Gitlab

All our coding is done openly on [Gitlab](https://git.nullivex.com/kado/kado)
where you an create an account and start working on Merge Requests yourself.
Our code has been fully peer reviewed and records of the review can be seen
in our issues tracker. We hope to see your contribution soon!

==> kado-4.2.1.tgz: package/doc/article/Kado4Released.md <==
# Kado 4 Released
*By Bryan Tong on 2/19/20*

We are proud to announce Kado 4 has been released to the general public! Our new
version of Kado has been 6 months in the making, over 550+ commits. There are
37 top level libraries that provide a wealth of functionality! All the code
strictly follows [standard.js](https://standardjs.com) code styling.

Kado 4 is a ground up rewrite working through a new approach to providing the
same functionality as Kado 3 in a much more open manner. Kado 4 also provides
core libraries that replace the need for over 50+ packages! Kado 4 is fully
unit tested with over 600 tests!

## Faster than Ever

We set a primary goal when developing Kado 4 and that was to reduce the latency
of web requests. Our current applications were just too slow. Kado 4 boosts
response time by over 50 times and probably more! The time on requests drops
closer to compiled levels with Kado 4 and we promise it will out perform your
current setup.

## Create Websites and API Servers

The new Kado libraries come with enough functionality to setup both websites
and API servers right out of the box. No extra dependencies needed! The included
libraries provide everything to setup routes, process requests, and set
redirects. Keep working close to the core of Node.JS by using Kado for your next
servers.

## Step by Step Guides

Check out [kado.org](https://kado.org) if you are not already there and see
the **Guides** section at the left. The guides link together to form a step
by step introduction into using Kado 4 in your application.

## Built in Testing

Kado 4 is proud to announce the ability to write and run tests directly using
the included [TestRunner](../TestRunner.md) library. Also see the
[Writing Tests](../guide/WritingTests.md) guide to gain more understanding
on constructing test suites.

## Open Development with Gitlab

All our coding is done openly on [Gitlab](https://git.nullivex.com/kado/kado)
where you an create an account and start working on Merge Requests yourself.
Our code has been fully peer reviewed and records of the review can be seen
in our issues tracker. We hope to see your contribution soon!
